@@ -54,13 +54,14 @@ SIDE_PADDING = 10.0
 LINE_WIDTH = 3.0
 RECTANGLE_RADIUS = 5.0
 
-#GRR support api break in pygoocanvas 0.6/8.0 -> 0.9.0
-NEW_GOOCANVAS_API = goocanvas.pygoocanvas_version >= (0,9,0)
-
 class Canvas(goocanvas.Canvas):
     """
     This class manages many objects
     """
+    DND_TARGETS = [
+        ('conduit/element-name', 0, 0)
+    ]
+
     WELCOME_MESSAGE = _("Drag a Data Provider here to continue")
     def __init__(self, parentWindow, typeConverter, syncManager, dataproviderMenu, conduitMenu):
         """
@@ -86,7 +87,7 @@ class Canvas(goocanvas.Canvas):
 
         #set up DND from the treeview
         self.drag_dest_set(  gtk.gdk.BUTTON1_MASK | gtk.gdk.BUTTON3_MASK,
-                        conduit.gtkui.Tree.DND_TARGETS,
+                        self.DND_TARGETS,
                         gtk.gdk.ACTION_COPY | gtk.gdk.ACTION_LINK)
         self.connect('drag-motion', self.on_drag_motion)
         self.connect('size-allocate', self._canvas_resized)
@@ -102,6 +103,8 @@ class Canvas(goocanvas.Canvas):
 
         #model is a SyncSet, not set till later because it is loaded from xml
         self.model = None
+        
+        log.info("Goocanvas version: %s" % str(goocanvas.pygoocanvas_version))
 
     def _show_welcome_message(self):
         """
@@ -116,7 +119,7 @@ class Canvas(goocanvas.Canvas):
                                     x=c_w/2, 
                                     y=c_w/3, 
                                     width=3*c_w/5, 
-                                    text=Canvas.WELCOME_MESSAGE, 
+                                    text=self.WELCOME_MESSAGE, 
                                     anchor=gtk.ANCHOR_CENTER,
                                     alignment=pango.ALIGN_CENTER,
                                     font="Sans 10",
@@ -150,13 +153,9 @@ class Canvas(goocanvas.Canvas):
         return items
 
     def _canvas_resized(self, widget, allocation):
-        if NEW_GOOCANVAS_API:
-            self.set_bounds(0,0,allocation.width,allocation.height)
-            for i in self._get_child_conduit_canvas_items():
-                i.set_width(allocation.width)
-        else:
-            for i in self._get_child_conduit_canvas_items():
-                i.set_width(allocation.width)
+        self.set_bounds(0,0,allocation.width,allocation.height)
+        for i in self._get_child_conduit_canvas_items():
+            i.set_width(allocation.width)
 
 
     def _on_conduit_button_press(self, view, target, event):
@@ -320,7 +319,6 @@ class Canvas(goocanvas.Canvas):
                 for i in xrange(0, len(items)):
                     try:
                         overlap = items[i].get_bottom() - items[i+1].get_top()
-                        log.debug("Overlap: %s %s ----> %s" % (overlap,i,i+1))
                         if overlap != 0.0:
                             #translate all those below
                             for item in items[i+1:]:
@@ -420,6 +418,7 @@ class Canvas(goocanvas.Canvas):
         log.info("Configuring %s" % dp)
         #May block
         dp.configure(self.parentWindow)
+        self.selectedDataproviderItem.update_appearance()
 
     def on_refresh_dataprovider_clicked(self, widget):
         """
@@ -506,51 +505,27 @@ class _CanvasItem(goocanvas.Group):
         self.model = model
 
     def get_height(self):
-        if NEW_GOOCANVAS_API:
-            b = self.get_bounds()
-        else:
-            b = goocanvas.Bounds()
-            self.get_bounds(b)
+        b = self.get_bounds()
         return b.y2-b.y1
 
     def get_width(self):
-        if NEW_GOOCANVAS_API:
-            b = self.get_bounds()
-        else:
-            b = goocanvas.Bounds()
-            self.get_bounds(b)
+        b = self.get_bounds()
         return b.x2-b.x1
 
     def get_top(self):
-        if NEW_GOOCANVAS_API:
-            b = self.get_bounds()
-        else:
-            b = goocanvas.Bounds()
-            self.get_bounds(b)
+        b = self.get_bounds()
         return b.y1
 
     def get_bottom(self):
-        if NEW_GOOCANVAS_API:
-            b = self.get_bounds()
-        else:
-            b = goocanvas.Bounds()
-            self.get_bounds(b)
+        b = self.get_bounds()
         return b.y2
 
     def get_left(self):
-        if NEW_GOOCANVAS_API:
-            b = self.get_bounds()
-        else:
-            b = goocanvas.Bounds()
-            self.get_bounds(b)
+        b = self.get_bounds()
         return b.x1
 
     def get_right(self):
-        if NEW_GOOCANVAS_API:
-            b = self.get_bounds()
-        else:
-            b = goocanvas.Bounds()
-            self.get_bounds(b)
+        b = self.get_bounds()
         return b.x2
 
 class DataProviderCanvasItem(_CanvasItem):
@@ -566,12 +541,36 @@ class DataProviderCanvasItem(_CanvasItem):
 
     NAME_FONT = "Sans 8"
     STATUS_FONT = "Sans 7"
+    MAX_TEXT_LENGTH = 10
+    MAX_TEXT_LINES = 2
 
     def __init__(self, parent, model):
         _CanvasItem.__init__(self, parent, model)
 
         self._build_widget()
         self.set_model(model)
+        
+    def _get_model_name(self):
+        #FIXME: Goocanvas.Text does not ellipsize text,
+        #so we do it...... poorly
+        text = ""
+        lines = 1
+        for word in self.model.get_name().split(" "):
+            if len(word) > self.MAX_TEXT_LENGTH:
+                word = word[0:self.MAX_TEXT_LENGTH] + "... "
+            else:
+                word = word + " "
+
+            #gross guess for how much of the space we have used
+            if (len(text)+len(word))  > (self.MAX_TEXT_LENGTH*self.MAX_TEXT_LINES):
+                #append final elipsis
+                if not word.endswith("... "):
+                    text = text + "..."
+                break
+            else:
+                text = text + word
+            
+        return text
 
     def _get_fill_color(self):
         if self.model.module == None:
@@ -586,23 +585,6 @@ class DataProviderCanvasItem(_CanvasItem):
             else:
                 log.warn("Unknown module type: Cannot get fill color")
 
-    def _update_appearance(self):
-        #the image
-        pb = self._get_icon()
-        pbx = int((1*self.WIDGET_WIDTH/5) - (pb.get_width()/2))
-        pby = int((1*self.WIDGET_HEIGHT/3) - (pb.get_height()/2))
-        self.image.set_property("pixbuf",pb)
-
-        self.name.set_property("text",self.model.get_name())
-
-        if self.model.module == None:
-            statusText = self.PENDING_MESSAGE
-        else:
-            statusText = self.model.module.get_status_text()
-        self.statusText.set_property("text",statusText)
-
-        self.box.set_property("fill_color_rgba",self._get_fill_color())
-
     def _get_icon(self):
         return self.model.get_icon()        
 
@@ -628,7 +610,7 @@ class DataProviderCanvasItem(_CanvasItem):
         self.name = goocanvas.Text(  x=pbx + pb.get_width() + self.IMAGE_TO_TEXT_PADDING, 
                                 y=int(1*self.WIDGET_HEIGHT/3), 
                                 width=3*self.WIDGET_WIDTH/5, 
-                                text=self.model.get_name(), 
+                                text=self._get_model_name(), 
                                 anchor=gtk.ANCHOR_WEST, 
                                 font=self.NAME_FONT
                                 )
@@ -653,12 +635,29 @@ class DataProviderCanvasItem(_CanvasItem):
         log.debug("CHANGE DETECTED")
 
     def _on_status_changed(self, dataprovider):
-        msg = dataprovider.get_status_text()
+        msg = dataprovider.get_status()
         self.statusText.set_property("text", msg)
+        
+    def update_appearance(self):
+        #the image
+        pb = self._get_icon()
+        pbx = int((1*self.WIDGET_WIDTH/5) - (pb.get_width()/2))
+        pby = int((1*self.WIDGET_HEIGHT/3) - (pb.get_height()/2))
+        self.image.set_property("pixbuf",pb)
+
+        self.name.set_property("text",self._get_model_name())
+
+        if self.model.module == None:
+            statusText = self.PENDING_MESSAGE
+        else:
+            statusText = self.model.module.get_status()
+        self.statusText.set_property("text",statusText)
+
+        self.box.set_property("fill_color_rgba",self._get_fill_color())
 
     def set_model(self, model):
         self.model = model
-        self._update_appearance()
+        self.update_appearance()
         if self.model.module != None:
             self.model.module.connect("change-detected", self._on_change_detected)
             self.model.module.connect("status-changed", self._on_status_changed)
@@ -777,16 +776,14 @@ class ConduitCanvasItem(_CanvasItem):
         except KeyError: pass
 
     def _on_conduit_parameters_changed(self, cond):
-        #update the twowayness of the connectors
-        for c in self.connectorItems.values():
-            c.set_two_way(self.model.is_two_way())
+        self.update_appearance()
 
     def _on_conduit_dataprovider_changed(self, cond, olddpw, newdpw):
         for item in [self.sourceItem] + self.sinkDpItems:
             if item.model.get_key() == olddpw.get_key():
                 item.set_model(newdpw)
 
-    def _on_conduit_progress(self, cond, percent):
+    def _on_conduit_progress(self, cond, percent, UIDs):
         self.progressText.set_property("text","%2.1d%% complete" % int(percent*100.0))
 
     def _get_connector_coordinates(self, fromdp, todp):
@@ -830,6 +827,13 @@ class ConduitCanvasItem(_CanvasItem):
                         break
 
 
+    def update_appearance(self):
+        self._resize_height()
+    
+        #update the twowayness of the connectors
+        for c in self.connectorItems.values():
+            c.set_two_way(self.model.is_two_way())
+
     def add_dataprovider_canvas_item(self, item):
         self._position_dataprovider(item)
 
@@ -875,9 +879,8 @@ class ConduitCanvasItem(_CanvasItem):
                     )
                 self.connectorItems[item] = c
 
-        self._resize_height()
         self._add_progress_text()
-
+        self.update_appearance()
 
     def delete_dataprovider_canvas_item(self, item):
         """
@@ -898,8 +901,8 @@ class ConduitCanvasItem(_CanvasItem):
             self.sinkDpItems.remove(item)
             self._delete_connector(item)
 
-        self._resize_height()
         self._remove_overlap()
+        self.update_appearance()
 
     def set_height(self, h):
         self.bounding_box.set_property("height",h)
